@@ -7,10 +7,11 @@
 #ifndef EVENTMODEL_H
 #define EVENTMODEL_H
 
+#include "localcalendar.h"
+
 #include <QAbstractListModel>
 #include <KCalendarCore/Event>
 
-class LocalCalendar;
 class SettingsController;
 
 class EventModel : public QAbstractListModel
